Module: check_mk
Branch: master
Commit: 46a0b5198e165eb54d758852dedfb3c27008da1d
URL: http://git.mathias-kettner.de/git/?p=check_mk.git;a=commit;h=46a0b5198e165e…
Author: Marcel Arentz <ma(a)mathias-kettner.de>
Date: Fri Oct 13 10:32:02 2017 +0200
Fixed angle brackets in manpage
Change-Id: I6582e6c33a3e4ca185090d38e7714ea622d085d1
---
checkman/local | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/checkman/local b/checkman/local
index 5c9814f..8cbe76d 100644
--- a/checkman/local
+++ b/checkman/local
@@ -5,7 +5,7 @@ license: GPL
distribution: check_mk
description:
This check type processes the output of the checks the
- agent sends in the {<<<local>>>} section. Local checks are
+ agent sends in the {<<<local>>>} section. Local checks are
implemented by scripts or programs running on the target
hosts. Please refer to the online documentation details about
how to write those check scripts.
Module: check_mk
Branch: master
Commit: 97926f2f41b648f67213f17746b9534757702395
URL: http://git.mathias-kettner.de/git/?p=check_mk.git;a=commit;h=97926f2f41b648…
Author: Konstantin Büttner <kb(a)mathias-kettner.de>
Date: Fri Oct 13 10:03:53 2017 +0200
5225 apache_status: Change autodetection logic of agent plugin to include a process multiple times if it listens on multiple ports
Change-Id: Iac3d0557ed60ef6c5326051653b6f1d80ef5f5ec
---
.werks/5225 | 10 ++++++++++
agents/plugins/apache_status | 6 ------
2 files changed, 10 insertions(+), 6 deletions(-)
diff --git a/.werks/5225 b/.werks/5225
new file mode 100644
index 0000000..ab7f931
--- /dev/null
+++ b/.werks/5225
@@ -0,0 +1,10 @@
+Title: apache_status: Change autodetection logic of agent plugin to include a process multiple times if it listens on multiple ports
+Level: 1
+Component: checks
+Compatible: compat
+Edition: cre
+Version: 1.5.0i1
+Date: 1507881782
+Class: feature
+
+
diff --git a/agents/plugins/apache_status b/agents/plugins/apache_status
index d92f15d..c97e8bc 100755
--- a/agents/plugins/apache_status
+++ b/agents/plugins/apache_status
@@ -65,7 +65,6 @@ if os.path.exists(config_file):
def try_detect_servers():
- pids = []
results = []
for line in os.popen('netstat -tlnp 2>/dev/null').readlines():
@@ -88,11 +87,6 @@ def try_detect_servers():
if proc not in procs:
continue
- # Add only the first found port of a single server process
- if pid in pids:
- continue
- pids.append(pid)
-
address, port = parts[3].rsplit(':', 1)
port = int(port)
Module: check_mk
Branch: master
Commit: 09e3cfb2f83920c6ad7a0949c058f9f564a9b31b
URL: http://git.mathias-kettner.de/git/?p=check_mk.git;a=commit;h=09e3cfb2f83920…
Author: Konstantin Büttner <kb(a)mathias-kettner.de>
Date: Thu Oct 12 16:24:10 2017 +0200
5224 check_http: Support verbose output
This allows to use the -v option of the classic check_http active check.
This will extend the long output of the plugin by header and body information.
Change-Id: I6f2322cec77023e3950fbf848754fac4ade2b516
---
.werks/5224 | 11 +++++++++++
checks/check_http | 3 +++
web/plugins/wato/active_checks.py | 5 +++++
3 files changed, 19 insertions(+)
diff --git a/.werks/5224 b/.werks/5224
new file mode 100644
index 0000000..1416eb4
--- /dev/null
+++ b/.werks/5224
@@ -0,0 +1,11 @@
+Title: check_http: Support verbose output
+Level: 1
+Component: checks
+Compatible: compat
+Edition: cre
+Version: 1.5.0i1
+Date: 1507818178
+Class: feature
+
+This allows to use the -v option of the classic check_http active check.
+This will extend the long output of the plugin by header and body information.
diff --git a/checks/check_http b/checks/check_http
index 44f1a62..aaa6e27 100644
--- a/checks/check_http
+++ b/checks/check_http
@@ -28,6 +28,9 @@ def check_http_arguments(params):
description, settings = params
args = []
+ if "verbose" in settings:
+ args += [ "-v" ]
+
if "vhost" in settings:
args += [ "-H", settings["vhost"] ]
diff --git a/web/plugins/wato/active_checks.py b/web/plugins/wato/active_checks.py
index 520bfce..ce015c6 100644
--- a/web/plugins/wato/active_checks.py
+++ b/web/plugins/wato/active_checks.py
@@ -1142,6 +1142,11 @@ register_rule(group,
"like the connect time, header time, time till first byte received and the "
"transfer time."),
)),
+ ( "verbose", FixedValue(
+ value=True,
+ title=_("Verbose output"),
+ totext=_("Give verbose output"),
+ )),
]
),
Module: check_mk
Branch: master
Commit: 69ad9c41aedae232398cf96be438eddd2f5a1fde
URL: http://git.mathias-kettner.de/git/?p=check_mk.git;a=commit;h=69ad9c41aedae2…
Author: Lars Michelsen <lm(a)mathias-kettner.de>
Date: Thu Oct 12 15:29:07 2017 +0200
"Add to" visual/pagetype gets more info about graphs
* CSV export of graphs respects the current graph data range now
* When adding a graph to a visual (dashboard, report) or pagetype (graph
collection, custom graph) the grah tells the "add to" function now
more than the graph specification. The function could now also use
the data range somehow.
However, the new information are currently not used by the "add to"
functions.
Change-Id: I3953685117e565927bd157bba3c6e64a3762654c
---
web/htdocs/dashboard.py | 21 ++++++++++++---------
web/htdocs/js/checkmk.js | 3 ++-
2 files changed, 14 insertions(+), 10 deletions(-)
diff --git a/web/htdocs/js/checkmk.js b/web/htdocs/js/checkmk.js
index 33b35d6..1790116 100644
--- a/web/htdocs/js/checkmk.js
+++ b/web/htdocs/js/checkmk.js
@@ -3265,7 +3265,8 @@ function pagetype_add_to_container(page_type, page_name)
function graph_export()
{
var request = {
- "specification": popup_data[2]
+ "specification": popup_data[2]["definition"]["specification"],
+ "data_range": popup_data[2]["data_range"],
};
location.href = "graph_export.py?request=" + encodeURIComponent(JSON.stringify(request));
}
diff --git a/web/htdocs/dashboard.py b/web/htdocs/dashboard.py
index 24cfed1..145935e 100644
--- a/web/htdocs/dashboard.py
+++ b/web/htdocs/dashboard.py
@@ -1296,33 +1296,36 @@ def popup_add_dashlet(dashboard_name, dashlet_type, context, params):
return
if dashlet_type == "pnpgraph":
# Context will always be None here, but the graph_identification (in params)
# will contain it. Transform the data to the format needed by the dashlets.
# Example:
# params = [ 'template', {'service_description': 'CPU load', 'site': 'mysite',
# 'graph_index': 0, 'host_name': 'server123'}])
- graph_identification = params[1]
- if params[0] == "template":
+ specification = params["definition"]["specification"]
+ if specification[0] == "template":
context = {
- "host" : graph_identification["host_name"]
+ "host" : specification[1]["host_name"]
}
- if graph_identification.get("service_description") != "_HOST_":
- context["service"] = graph_identification["service_description"]
+ if specification[1].get("service_description") != "_HOST_":
+ context["service"] = specification[1]["service_description"]
params = {
- "source" : graph_identification["graph_index"] + 1
+ "source" : specification[1]["graph_index"] + 1
}
- elif params[0] == "custom":
+ elif specification[0] == "custom":
# Override the dashlet type here. It would be better to get the
# correct dashlet type from the menu. But this does not seem to
# be a trivial change.
dashlet_type = "custom_graph"
context = {}
params = {
- "custom_graph": params[1],
+ "custom_graph": specification[1],
}
+ else:
+ raise MKGeneralException(_("Invalid graph type '%s'") % specification[0])
+
load_dashboards(lock=True)
@@ -1296,33 +1296,36 @@ def popup_add_dashlet(dashboard_name, dashlet_type, context, params):
return
if dashlet_type == "pnpgraph":
- # Context will always be None here, but the graph_identification (in params)
+ # Context will always be None here, but the specification (in params)
# will contain it. Transform the data to the format needed by the dashlets.
# Example: